==> pegasus-merchandise-api-2.6.8-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpChnCanSaleProdCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpChannelCanSaleSkuCond.java, v 0.1 2015-08-04 15:52
 */
public class OpChnCanSaleProdCond extends BaseQueryCond {

    /**
     * 渠道编码
     */
//    private String channelCode;
    private String channelName;
    private String productCode;
    private String productName;

    private String skuCode;
    private String chnCode;
    private List<String> chnCodeList;

    private Integer onShelf;



    private Integer categoryId;
    private Integer brandId;
    private Date createTimeStart;
    private Date createTimeEnd;

    private Integer createUserId;

    private Long  productId;
    private List<Long> accessWayIds;
    private List<String> productCodeList;
    private List<Long> productIdList;

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getChnCode() {
        return chnCode;
    }

    public void setChnCode(String chnCode) {
        this.chnCode = chnCode;
    }

    public List<String> getChnCodeList() {
        return chnCodeList;
    }

    public void setChnCodeList(List<String> chnCodeList) {
        this.chnCodeList = chnCodeList;
    }

    public Integer getOnShelf() {
        return onShelf;
    }

    public void setOnShelf(Integer onShelf) {
        this.onShelf = onShelf;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Integer getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Integer categoryId) {
        this.categoryId = categoryId;
    }

    public Integer getBrandId() {
        return brandId;
    }

    public void setBrandId(Integer brandId) {
        this.brandId = brandId;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }


    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public List<Long> getAccessWayIds() {
        return accessWayIds;
    }

    public void setAccessWayIds(List<Long> accessWayIds) {
        this.accessWayIds = accessWayIds;
    }

    public List<String> getProductCodeList() {
        return productCodeList;
    }

    public void setProductCodeList(List<String> productCodeList) {
        this.productCodeList = productCodeList;
    }

    public List<Long> getProductIdList() {
        return productIdList;
    }

    public void setProductIdList(List<Long> productIdList) {
        this.productIdList = productIdList;
    }
}

==> pegasus-merchandise-api-2.8.3-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpChnCanSaleProdCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;
import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpChannelCanSaleSkuCond.java, v 0.1 2015-08-04 15:52
 */
public class OpChnCanSaleProdCond extends BaseQueryCond {

    /**
     * 渠道编码
     */
//    private String channelCode;
    private String channelName;
    private String productCode;
    private String productName;

    private String skuCode;
    private String chnCode;
    private List<String> chnCodeList;

    private Integer onShelf;



    private Integer categoryId;
    private Integer brandId;
    private Date createTimeStart;
    private Date createTimeEnd;

    private Integer createUserId;

    private Long  productId;
    private List<Long> accessWayIds;
    private List<String> productCodeList;
    private List<Long> productIdList;

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getChnCode() {
        return chnCode;
    }

    public void setChnCode(String chnCode) {
        this.chnCode = chnCode;
    }

    public List<String> getChnCodeList() {
        return chnCodeList;
    }

    public void setChnCodeList(List<String> chnCodeList) {
        this.chnCodeList = chnCodeList;
    }

    public Integer getOnShelf() {
        return onShelf;
    }

    public void setOnShelf(Integer onShelf) {
        this.onShelf = onShelf;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Integer getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Integer categoryId) {
        this.categoryId = categoryId;
    }

    public Integer getBrandId() {
        return brandId;
    }

    public void setBrandId(Integer brandId) {
        this.brandId = brandId;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }


    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public List<Long> getAccessWayIds() {
        return accessWayIds;
    }

    public void setAccessWayIds(List<Long> accessWayIds) {
        this.accessWayIds = accessWayIds;
    }

    public List<String> getProductCodeList() {
        return productCodeList;
    }

    public void setProductCodeList(List<String> productCodeList) {
        this.productCodeList = productCodeList;
    }

    public List<Long> getProductIdList() {
        return productIdList;
    }

    public void setProductIdList(List<Long> productIdList) {
        this.productIdList = productIdList;
    }
}
